<!--header-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="text" omit-xml-declaration="yes" indent="no"/>
    <xsl:template match="/">
    <!-- End of header-->
      <!--Loop reading attributes of every object in the auto-generated XML created of Windchill-data;
        root/element/items describes the parent structure enclosing the looked for attributes; 
        most attributes will be found under <attributes/attributename>-->
        <xsl:for-each select="root/element/items">
        <!--Narrowing down the data received from Windchill; 
        otherwise all the data received will be processed; 
        both possible if-clauses enclose the following statements;
        they will only end at the end of the file with '</xsl:if>' right above the end of the 'for-each'-loop
        The overall context is found in the tree under 'container' the workspace is defined by 'folder';  
        Two Options: Excluding Objects that shall not be transferred or including those that shall be transferred
        Exclude-option: Use this version if there are other loose objects not assigned to a special folder.
        Just replace the names of the folders between the ''. Data of these Windchill-folders will not be transferred;
        <xsl:if test="normalize-space(attributes/container) = 'Genius Tools Library' and normalize-space(attributes/folder)!='/Default/config' and normalize-space(attributes/folder)!='/Default/frm_formats' and normalize-space(attributes/folder)!='/Default/gph_groups' and normalize-space(attributes/folder)!='/Default/start_templates'">
        Include-option: Use this version to receive only data from specific folders: -->
          <xsl:if test="normalize-space(attributes/container) = 'Genius Tools Library' and normalize-space(attributes/folder)='/Default/test_gle'">
            <!-- if-clause to select the attribute 'CADName' of every object received from Windchill; in order to define the GT Library attributes 'name' and 'objType'-->
            <xsl:if test="attributes/CADName and normalize-space(attributes/CADName)!=''">
            <!--Creating a string consisting of 'name=' and 'CADName' of the current object as found in the processed XML followed by a return(&#xa;)-->
              <xsl:text>name=</xsl:text>
              <xsl:value-of select="normalize-space(attributes/CADName)"/>
              <xsl:text>&#xa;</xsl:text>
            <!--Creating a string consisting of 'objType=' and a value corresponding to the file extension, defining if the current of object is a drawing, a part etc. followed by a return after the choose process is concluded(&#xa;)
            The 'choose/when' operation differentiates between given file extensions; the 'otherwise' statement after the when-clause sets every not predefined extension to value '-1'-->
              <xsl:text>objType=</xsl:text>
                <xsl:choose> 
                  <xsl:when test="contains(attributes/CADName,'.asm')"> 
                    <xsl:value-of select="20"/>
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.prt')"> 
                    <xsl:value-of select="10"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.drw')"> 
                    <xsl:value-of select="30"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.sec')"> 
                    <xsl:value-of select="40"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.gph')"> 
                    <xsl:value-of select="50"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.mfg')"> 
                    <xsl:value-of select="60"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.lay')"> 
                    <xsl:value-of select="70"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.dgm')"> 
                    <xsl:value-of select="80"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.frm')"> 
                    <xsl:value-of select="90"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.tbl')"> 
                    <xsl:value-of select="100"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.sym')"> 
                    <xsl:value-of select="110"/> 
                  </xsl:when>
                  <xsl:when test= "contains(attributes/CADName,'.txt')"> 
                    <xsl:value-of select="120"/> 
                  </xsl:when>
                  <xsl:otherwise>
                    <xsl:value-of select="-1"/> 
                  </xsl:otherwise>
                </xsl:choose> 
              <xsl:text>&#xa;</xsl:text>
            </xsl:if>
            <!--creating the path in which library the object is found by concatenating 'wtpub://PDM/Bibliotheken' and the 'folder'-attribute followed by a return-->
            <xsl:if test="attributes/container and attributes/folder and normalize-space(attributes/container)!=''">
              <xsl:text>path=</xsl:text>
              <xsl:value-of select="concat('wtpub://PDM/Bibliotheken', '/', normalize-space(attributes/container), normalize-space(attributes/folder))"/>  
              <xsl:text>&#xa;</xsl:text>
            </xsl:if>
            <!--creating the parameter 'Revision' as an example parameter. The select chooses the attribute 'version' from which the parameter 'revision' is derived
            Use 'P:PARAMETERNAME=' for every parameter you wish to add and insert the attribute you want to save as this parameter or the concatenation of different attributes; every value has to be followed by a return('&#xa;')-->
            <xsl:if test="attributes/version and normalize-space(attributes/version) !=''">
              <xsl:text>P:REVISION=</xsl:text>
              <xsl:value-of select="normalize-space(attributes/version)"/>
              <xsl:text>&#xa;</xsl:text> 
            </xsl:if>
            <!--another example parameter-->
            <xsl:if test="attributes/MATERIAL and normalize-space(attributes/MATERIAL)!=''">
              <xsl:text>P:MATERIAL=</xsl:text>
              <xsl:value-of select="normalize-space(attributes/MATERIAL)"/>
              <xsl:text>&#xa;</xsl:text> 
            </xsl:if>
            <!--For dimensions use 'D:dimensionname=' and proceed in analogy to the above-->
            <!--deriving the english title/description of the object if defined by the source material; 
            the if section tests if one of 'DESCRIPTION_1_EN' or 'DESCRIPTION_2_EN' or both are not empty
            the choose/when sections create a string 'title_en=' plus 'Description_1_EN' or a combination of 'Description_1_EN' and 'DESCRIPTION_2_EN' or 'DESCRIPTION_2_EN' depending which of those is not empty; in every case the will follow a return, unless both are empty, then it will be ignored-->      
            <xsl:if test="(attributes/DESCRIPTION_1_EN and normalize-space(attributes/DESCRIPTION_1_EN) !='') or (attributes/DESCRIPTION_2_EN and normalize-space(attributes/DESCRIPTION_2_EN) !='')">
              <xsl:choose>
                <xsl:when test="(attributes/DESCRIPTION_1_EN and attributes/DESCRIPTION_2_EN) and (normalize-space(attributes/DESCRIPTION_1_EN) !='') and (normalize-space(attributes/DESCRIPTION_2_EN) !='')">
                  <xsl:text>title_en=</xsl:text>
                  <xsl:value-of select="concat(normalize-space(attributes/DESCRIPTION_1_EN),'_', normalize-space(attributes/DESCRIPTION_2_EN))"/>
                  <xsl:text>&#xa;</xsl:text>
                </xsl:when>
                <xsl:when test="(((attributes/DESCRIPTION_1_EN and attributes/DESCRIPTION_2_EN) and (normalize-space(attributes/DESCRIPTION_1_EN) !='') and (normalize-space(attributes/DESCRIPTION_2_EN) ='')) or ((attributes/DESCRIPTION_1_EN and (not(attributes/DESCRIPTION_2_EN))) and (normalize-space(attributes/DESCRIPTION_1_EN) !='' )))">
                  <xsl:text>title_en=</xsl:text>
                  <xsl:value-of select="normalize-space(attributes/DESCRIPTION_1_EN)"/>
                  <xsl:text>&#xa;</xsl:text>
                </xsl:when>
                <xsl:when test="(((attributes/DESCRIPTION_1_EN and attributes/DESCRIPTION_2_EN) and (normalize-space(attributes/DESCRIPTION_1_EN) ='') and (normalize-space(attributes/DESCRIPTION_2_EN) !='')) or ((not(attributes/DESCRIPTION_1_EN) and (attributes/DESCRIPTION_2_EN)) and (normalize-space(attributes/DESCRIPTION_2_EN) !='' )))">
                  <xsl:text>title_en=</xsl:text>
                  <xsl:value-of select="normalize-space(attributes/DESCRIPTION_2_EN)"/>
                  <xsl:text>&#xa;</xsl:text>
                </xsl:when>
              <xsl:otherwise>
              </xsl:otherwise>
              </xsl:choose>
            </xsl:if>	
            <!--deriving the german title/description of the object if defined by the source material; 
            the if section tests if 'DESCRIPTION_1_DE' or 'DESCRIPTION_2_DE' or both are not empty
            the choose/when sections create a string 'title_de=' plus 'Description_1_DE' or a combination of 'Description_1_DE' and 'DESCRIPTION_2_DE' or 'DESCRIPTION_2_DE' depending which of those is not empty; in every case the will follow a return, unless both are empty, then it will be ignored-->
            <xsl:if test="(attributes/DESCRIPTION_1_DE and normalize-space(attributes/DESCRIPTION_1_DE) !='') or (attributes/DESCRIPTION_2_DE and normalize-space(attributes/DESCRIPTION_2_DE) !='')">
              <xsl:choose>
                <xsl:when test="(attributes/DESCRIPTION_1_DE and attributes/DESCRIPTION_2_DE) and (normalize-space(attributes/DESCRIPTION_1_DE) !='') and (normalize-space(attributes/DESCRIPTION_2_DE) !='')">
                  <xsl:text>title_de=</xsl:text>
                  <xsl:value-of select="concat(normalize-space(attributes/DESCRIPTION_1_DE),'_', normalize-space(attributes/DESCRIPTION_2_DE))"/>
                  <xsl:text>&#xa;</xsl:text>
                </xsl:when>
                <xsl:when test="(((attributes/DESCRIPTION_1_DE and attributes/DESCRIPTION_2_DE) and (normalize-space(attributes/DESCRIPTION_1_DE) !='') and (normalize-space(attributes/DESCRIPTION_2_DE) ='')) or ((attributes/DESCRIPTION_1_DE and (not(attributes/DESCRIPTION_2_DE))) and (normalize-space(attributes/DESCRIPTION_1_DE) !='' )))">
                  <xsl:text>title_de=</xsl:text>
                  <xsl:value-of select="normalize-space(attributes/DESCRIPTION_1_DE)"/>
                  <xsl:text>&#xa;</xsl:text>
                </xsl:when>
                <xsl:when test="(((attributes/DESCRIPTION_1_DE and attributes/DESCRIPTION_2_DE) and (normalize-space(attributes/DESCRIPTION_1_DE) ='') and (normalize-space(attributes/DESCRIPTION_2_DE) !='')) or ((not(attributes/DESCRIPTION_1_DE) and (attributes/DESCRIPTION_2_DE)) and (normalize-space(attributes/DESCRIPTION_2_DE) !='' )))">
                  <xsl:text>title_de=</xsl:text>
                  <xsl:value-of select="normalize-space(attributes/DESCRIPTION_2_DE)"/>
                  <xsl:text>&#xa;</xsl:text>
                </xsl:when>
              <xsl:otherwise>
              </xsl:otherwise>
              </xsl:choose>   
            </xsl:if>
            <!--Creating a parameter that enables GTL_DataImporter to detect if the current object has been changed since last last time it was processed-->
            <xsl:if test="attributes/thePersistInfo.modifyStamp and normalize-space(attributes/thePersistInfo.modifyStamp)!=''">
              <xsl:text>P:CHANGEDATE=</xsl:text>
              <xsl:value-of select="normalize-space(attributes/thePersistInfo.modifyStamp)"/>
              <xsl:text>&#xa;</xsl:text> 
            </xsl:if>
            <!--Creating the status attribute checking if the status attribute of the current object is released or not. if not it is set to '0' so it can be processed accordingly with creo/GT_Library -->
            <xsl:if test="attributes/state and normalize-space(attributes/state)!='Released'">
              <xsl:text>status=</xsl:text>
              <xsl:value-of select="0"/>
              <xsl:text>&#xa;</xsl:text>
            </xsl:if> 
            <!--Creating the attributes 'info' and 'thumbnail' from the Windchill attribute 'id'. NOTICE: 'id' is not part of the 'attributes' branch of the XML tree, therefore the if-clause tests on 'id' AND NOT on 'attributes/id'
            the 'info='-string is concatenating the standardized WINDCHILL-URI for object-ids with the actual id of the current object and an utf8 definition where the ampersand had to be substituted by the code for ampersand to be processed right
            the thumbnail just gets the id itself as a value-->   
            <xsl:if test="id and normalize-space(id)!=''">
              <xsl:text>info=</xsl:text>
              <xsl:value-of select="concat('http://wtpdmes02.ratc-de.com:81/Windchill/app/#ptc1/tcomp/infoPage?oid=',normalize-space(id),'&amp;amp;u8=1')"/>
            <xsl:text>&#xa;</xsl:text>
            <xsl:text>thumbnail=</xsl:text>
            <xsl:value-of select="normalize-space(id)"/>
            <xsl:text>&#xa;</xsl:text>
          </xsl:if>
          <!--final '-' and return to indicate the end of a single object; necessary for DataImporter to distinguish the two objects while processing all the data as a string-->
        <xsl:text>-&#xa;</xsl:text>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>                                                                     
</xsl:stylesheet> 

